use serde::{Deserialize, Serialize};
use std::collections::HashMap;

use crate::Well;

type WellPair = (Well, Well);

#[non_exhaustive]
#[derive(Debug, PartialEq, Deserialize, Serialize, Clone)]
pub enum TransferVolume {
    Single(f32),
    WellMap(VolumeMaps),
}

#[serde_with::serde_as]
#[derive(Debug, PartialEq, Deserialize, Serialize, Clone)]
pub struct VolumeMaps {
    #[serde_as(as = "HashMap<serde_with::json::JsonString, _>")]
    pub source_only: HashMap<Well, f32>,
    #[serde_as(as = "HashMap<serde_with::json::JsonString, _>")]
    pub destination_only: HashMap<Well, f32>,
    #[serde_as(as = "HashMap<serde_with::json::JsonString, _>")]
    pub paired: HashMap<WellPair, f32>,
}

impl Default for TransferVolume {
    fn default() -> Self {
        TransferVolume::Single(2.5f32)
    }
}
