#![allow(non_snake_case)]

use js_sys::Array;

use wasm_bindgen::{JsCast, JsValue};
use web_sys::{
    Blob, HtmlAnchorElement, Url,
};
use yew::prelude::*;


use crate::components::states::MainState;

use crate::state_to_csv;

// type NoParamsCallback = Box<dyn Fn(())>;

pub fn export_csv_button_callback(main_state: std::rc::Rc<MainState>) -> Callback<MouseEvent> {
    Callback::from(move |_| {
        if main_state.transfers.is_empty() {
            web_sys::window()
                .unwrap()
                .alert_with_message("No transfers to export.")
                .unwrap();
            return;
        }
        if let Ok(csv) = state_to_csv(&main_state) {
            save_str(&csv, "transfers.csv");
        }
    })
}

pub fn export_json_button_callback(main_state: std::rc::Rc<MainState>) -> Callback<MouseEvent> {
    Callback::from(move |_| {
        if let Ok(json) = serde_json::to_string(&main_state) {
            save_str(&json, "plate-tool-state.json");
        } else {
            web_sys::window()
                .unwrap()
                .alert_with_message("Failed to export.")
                .unwrap();
        }
    })
}

fn save_str(data: &str, name: &str) {
    let blob =
        Blob::new_with_str_sequence(&Array::from_iter(std::iter::once(JsValue::from_str(data))));
    if let Ok(blob) = blob {
        let url = Url::create_object_url_with_blob(&blob).expect("We have a blob, why not URL?");
        // Beneath is the cool hack to download files
        let window = web_sys::window().unwrap();
        let document = window.document().unwrap();
        let anchor = document
            .create_element("a")
            .unwrap()
            .dyn_into::<HtmlAnchorElement>()
            .unwrap();
        anchor.set_download(name);
        anchor.set_href(&url);
        anchor.click();
    }
}
