#![allow(non_snake_case)]

use yew::prelude::*;
use yewdux::prelude::*;

use crate::components::{new_plate_dialog::{NewPlateDialogType}, states::{CurrentTransfer, MainState}};

type NoParamsCallback = Box<dyn Fn(())>;

pub fn new_plate_dialog_callback(
    new_plate_dialog_is_open: UseStateHandle<Option<NewPlateDialogType>>,
) -> NoParamsCallback {
    let new_plate_dialog_is_open = new_plate_dialog_is_open.clone();
    Box::new(move |_| {
        new_plate_dialog_is_open.set(None);
    })
}

pub fn open_new_plate_dialog_callback(
    new_plate_dialog_is_open: UseStateHandle<Option<NewPlateDialogType>>
) -> Box<dyn Fn(NewPlateDialogType)> {
    let new_plate_dialog_is_open = new_plate_dialog_is_open.clone();
    Box::new(move |dt| {
        new_plate_dialog_is_open.set(Some(dt));
    })
}

pub fn new_button_callback(
    main_dispatch: Dispatch<MainState>,
    ct_dispatch: Dispatch<CurrentTransfer>,
) -> Callback<web_sys::MouseEvent> {
    Callback::from(move |_| {
        let window = web_sys::window().unwrap();
        let confirm =
            window.confirm_with_message("This will reset all plates and transfers. Proceed?");
        if let Ok(confirm) = confirm {
            if confirm {
                main_dispatch.set(MainState::default());
                ct_dispatch.set(CurrentTransfer::default());
            }
        }
    })
}
